@@ -1,8 +1,5 @@
 require 'minitest/spec'
 
-require 'minitest/versions'
-require_relative 'backwards'
-
 require 'minispec-metadata/version'
 
 require 'minispec-metadata/it'
