@@ -5,14 +5,14 @@ require_relative 'helper'
 describe "top level describe" do
   describe "an inner describe" do
     before do
-      desc.wont_be_nil
+      _(desc).wont_be_nil
     end
     it "an example inside inner describe" do
-      desc.must_equal 'an example inside inner describe'
+      _(desc).must_equal 'an example inside inner describe'
     end
   end
 
   it "another top level example" do
-    desc.must_equal 'another top level example'
+    _(desc).must_equal 'another top level example'
   end
 end
